Learn R Programming

BMhyb (version 2.1.5)

GetConvexHull: Get convex hull at a given threshold

Description

For a given delta lnL, get the convex hull (blob encircling the points) for two dimensions

Usage

GetConvexHull(threshold = 2, df, height, x, y)

Arguments

threshold

What value to exclude numbers worse than

df

The data.frame

height

The variable name to use for the height threshold

x

The first variable to look at for the hull

y

The second variable to look at for the hull