For a given delta lnL, get the convex hull (blob encircling the points) for two dimensions
GetConvexHull(threshold = 2, df, height, x, y)What value to exclude numbers worse than
The data.frame
The variable name to use for the height threshold
The first variable to look at for the hull
The second variable to look at for the hull